@@ -2,7 +2,7 @@ use strict;
 use warnings;
 use 5.022;
 
-package Alien::Build::Wizard 0.02 {
+package Alien::Build::Wizard 0.03 {
 
   use Moose;
   use Moose::Util::TypeConstraints;
@@ -69,7 +69,18 @@ package Alien::Build::Wizard 0.02 {
     isa     => 'URI',
     lazy    => 1,
     default => sub ($self) {
-      $self->detect->uri;
+      if($self->latest)
+      {
+        my $url = $self->detect->uri->clone;
+        my $path = $url->path;
+        $path =~ s{/[^/]*?$}{};
+        $url->path($path);
+        return $url;
+      }
+      else
+      {
+        return $self->detect->uri;
+      }
     },
   );
 
@@ -158,12 +169,40 @@ package Alien::Build::Wizard 0.02 {
     }
   );
 
+  has latest => (
+    is      => 'ro',
+    isa     => 'Int',
+    lazy    => 1,
+    default => sub ($self) {
+      my $value = $self->chrome->choose(QUESTION_LATEST, ['latest','specific'], ['latest']);
+      $value eq 'latest' ? 1 : 0;
+    },
+  );
+
+  has prefix => (
+    is      => 'ro',
+    isa     => 'Str',
+    lazy    => 1,
+    default => sub ($self) {
+      my $path = $self->detect->uri->path;
+      my($file) = $path =~ /\/([^\/]*?)$/;
+      my($prefix) = $file =~ /^([^-^\.]+)/;
+      $prefix;
+    }
+  );
+
   sub generate_content ($self)
   {
     my %files;
 
     require Template;
-    my $tt = Template->new;
+    my $tt = Template->new(
+      FILTERS => {
+        regex_escape => sub ($text) { $text =~ s/\./\\./gr },
+      },
+    );
+
+    my $pod = sub ($name) { "=$name" };
 
     {
       my $pm = 'lib/' . $self->class_name . ".pm";
@@ -171,7 +210,7 @@ package Alien::Build::Wizard 0.02 {
       my $template = get_data_section 'Module.pm';
       $template =~ s/\s+$/\n/;
       die "no template Module.pm" unless $template;
-      $tt->process(\$template, { wizard => $self }, \($files{$pm} = '')) or die $tt->error;
+      $tt->process(\$template, { wizard => $self, pod => $pod }, \($files{$pm} = '')) or die $tt->error;
     }
 
     foreach my $path (qw( alienfile t/basic.t ))
@@ -179,7 +218,7 @@ package Alien::Build::Wizard 0.02 {
       my $template = get_data_section $path;
       $template =~ s/\s+$/\n/;
       die "no template $path" unless $template;
-      $tt->process(\$template, { wizard => $self }, \($files{$path} = '')) or die $tt->error;
+      $tt->process(\$template, { wizard => $self, pod => $pod }, \($files{$path} = '')) or die $tt->error;
     }
 
     \%files;
@@ -201,7 +240,7 @@ Alien::Build::Wizard - Alien distribution creation wizard
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 SYNOPSIS
 
@@ -244,11 +283,11 @@ use 5.008004;
 
 1;
 
-=head1 NAME
+[% pod('head1') %] NAME
 
 [% wizard.class_name %] - Find or build [% wizard.human_name %]
 
-=head1 SYNOPSIS
+[% pod('head1') %] SYNOPSIS
 [%- IF wizard.alien_types.xs %]
 
 From L<ExtUtils::MakeMaker>:
@@ -320,7 +359,7 @@ Command line tool:
  unshift @PATH, [% wizard.class_name %]->bin_dir;
 [%- END %]
 
-=head1 DESCRIPTION
+[% pod('head1') %] DESCRIPTION
 
 This distribution provides [% wizard.human_name %] so that it can be used by other
 Perl distributions that are on CPAN.  It does this by first trying to
@@ -329,25 +368,25 @@ will use that.  If it cannot be found, the source code will be downloaded
 from the internet and it will be installed in a private share location
 for the use of other modules.
 
-=head1 SEE ALSO
+[% pod('head1') %] SEE ALSO
 
-=over 4
+[% pod('over') %] 4
 
-=item L<Alien>
+[% pod('item') %] L<Alien>
 
 Documentation on the Alien concept itself.
 
-=item L<Alien::Base>
+[% pod('item') %] L<Alien::Base>
 
 The base class for this Alien.
 
-=item L<Alien::Build::Manual::AlienUser>
+[% pod('item') %] L<Alien::Build::Manual::AlienUser>
 
 Detailed manual for users of Alien classes.
 
-=back
+[% pod('back') %]
 
-=cut
+[% pod('cut') %]
 
 @@ alienfile
 use alienfile;
@@ -364,7 +403,14 @@ probe sub { 'share' }
 
 share {
   start_url '[% wizard.start_url %]';
+[% IF wizard.latest -%]
+  plugin Download => (
+    filter  => qr/^[% wizard.prefix %].*[% wizard.extract_format | regex_escape %]$/,
+    version => qr/([0-9\.]+)/,
+  );
+[% ELSE -%]
   plugin Download => ();
+[% END -%]
 [% IF wizard.extract_format == 'fixme' -%]
 
   # archive format was not detected, see
